durationtools.duration_token_to_duration_pair
=============================================

.. autofunction:: abjad.tools.durationtools.duration_token_to_duration_pair.duration_token_to_duration_pair
